Repository: guacamole-client
Updated Branches:
  refs/heads/master d73a0ece2 -> c170612cd


GUACAMOLE-237: Move to new getUserMedia method.


Project: http://git-wip-us.apache.org/repos/asf/guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/guacamole-client/commit/1c27c66c
Tree: http://git-wip-us.apache.org/repos/asf/guacamole-client/tree/1c27c66c
Diff: http://git-wip-us.apache.org/repos/asf/guacamole-client/diff/1c27c66c

Branch: refs/heads/master
Commit: 1c27c66cb345536574348aa7a1102cbc0859243d
Parents: d73a0ec
Author: Nick Couchman <[email protected]>
Authored: Mon Jan 1 22:11:45 2018 -0500
Committer: Nick Couchman <[email protected]>
Committed: Mon Jan 1 22:11:45 2018 -0500

----------------------------------------------------------------------
 guacamole-common-js/src/main/webapp/modules/AudioRecorder.js | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/guacamole-client/blob/1c27c66c/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
----------------------------------------------------------------------
diff --git a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js 
b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
index 954b79f..f925716 100644
--- a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
+++ b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
@@ -183,11 +183,12 @@ Guacamole.RawAudioRecorder = function 
RawAudioRecorder(stream, mimetype) {
 
     /**
      * A function which directly invokes the browser's implementation of
      * navigator.getUserMedia() with all provided parameters.
      *
      * @type Function
      */
-    var getUserMedia = (navigator.getUserMedia
+    var getUserMedia = (navigator.mediaDevices.getUserMedia
+            || navigator.getUserMedia
             || navigator.webkitGetUserMedia
             || navigator.mozGetUserMedia
             || navigator.msGetUserMedia).bind(navigator);
@@ -183,11 +183,12 @@ Guacamole.RawAudioRecorder = function 
     /**
      * A function which directly invokes the browser's implementation of
-     * navigator.getUserMedia() with all provided parameters.
+     * navigator.mediaDevices.getUserMedia() with all provided parameters.
      *
      * @type Function

Reply via email to